<?php

namespace Drupal\Tests\decoupled_quiz\Functional;

use Drupal\Tests\BrowserTestBase;
use Drupal\Tests\decoupled_quiz\Traits\DecoupledQuizHelperTrait;

/**
 * Simple test to ensure Quiz Entity can be opened by administrator.
 *
 * @group decoupled_quiz
 */
class QuizTest extends BrowserTestBase {

  use DecoupledQuizHelperTrait;

  /**
   * {@inheritdoc}
   */
  public static $modules = ['text', 'field', 'decoupled_quiz'];

  /**
   * {@inheritdoc}
   */
  protected $quiz;

  /**
   * {@inheritdoc}
   */
  protected $user;

  /**
   * {@inheritdoc}
   */
  public function setUp() {
    parent::setUp();

    $this->quiz = $this->createQuiz();
    $this->user = $this->createAdminUser();
    $this->drupalLogin($this->user);
  }

  /**
   * {@inheritdoc}
   */
  public function testQuizAdminView() {
    $this->drupalGet('admin/structure/quiz/' . $this->quiz->id());
    $this->assertSession()->statusCodeEquals(200);
    $this->assertSession()->pageTextContains('Test Quiz');
  }

  /**
   * {@inheritdoc}
   */
  public function testQuizAdminEdit() {
    $name = 'name[0][value]';
    $description = 'field_quiz_intro_description[0][value]';
    $edit[$name] = $this->randomMachineName();
    $edit[$description] = $this->randomMachineName(36);
    $this->drupalPostForm('admin/structure/quiz/add/recommendation', $edit, t('Save'));
    $quiz = $this->getQuizByName($edit[$name]);
    $this->assertTrue($quiz);

    $this->drupalGet('admin/structure/quiz/' . $quiz->id());
    $this->assertSession()->pageTextContains($edit[$name]);
    $this->assertSession()->pageTextContains($edit[$description]);
  }

}
