<?php

namespace Drupal\Tests\decoupled_quiz\Traits;

use Drupal\decoupled_quiz\Entity\Answer;
use Drupal\decoupled_quiz\Entity\Question;
use Drupal\decoupled_quiz\Entity\Quiz;
use Drupal\user\Entity\User;

/**
 * Provides Decoupled Quiz helper methods.
 */
trait DecoupledQuizHelperTrait {

  /**
   * Creates Admin user.
   */
  protected function createAdminUser() {
    $edit = [
      'name' => $this->randomMachineName(),
      'mail' => $this->randomMachineName() . '@example.com',
      'pass' => user_password(),
      'status' => 1,
      'roles' => $this->createAdminRole(),
    ];

    $account = User::create($edit);
    $account->save();
    $account->pass_raw = $account->passRaw = $edit['pass'];

    return $account;
  }

  /**
   * Creates Test Quiz.
   */
  protected function createQuiz() {
    $question = $this->createQuestion();
    $quiz = Quiz::create([
      'type' => 'recommendation',
      'name' => 'Test Quiz',
      'field_recommendation_questions' => [$question->id()],
    ]);
    $quiz->save();
    return $quiz;
  }

  /**
   * Creates Test Question.
   */
  protected function createQuestion() {
    $answer = $this->createAnswer();
    $question = Question::create([
      'type' => 'basic_question',
      'field_basic_question_answers' => [$answer->id()],
      'name' => 'Test Question',
    ]);
    $question->save();
    return $question;
  }

  /**
   * Creates Test Answer.
   */
  protected function createAnswer() {
    $answer = Answer::create(['type' => 'basic_answer'])->setName('Test Answer');
    $answer->save();
    return $answer;
  }

  /**
   * Returns Quiz by name.
   */
  protected function getQuizByName($title) {
    $title = (string) $title;
    $quizzes = \Drupal::entityTypeManager()
      ->getStorage('quiz')
      ->loadByProperties(['name' => $title]);
    // Load the first quiz returned from the database.
    $quiz = reset($quizzes);
    return $quiz;
  }

  /**
   * Returns Question by name.
   */
  protected function getQuestionByName($title) {
    $title = (string) $title;
    $questions = \Drupal::entityTypeManager()
      ->getStorage('question')
      ->loadByProperties(['name' => $title]);
    // Load the first question returned from the database.
    $question = reset($questions);
    return $question;
  }

  /**
   * Returns Answer by name.
   */
  protected function getAnswerByName($title) {
    $title = (string) $title;
    $answer = \Drupal::entityTypeManager()
      ->getStorage('answer')
      ->loadByProperties(['name' => $title]);
    // Load the first answer returned from the database.
    $answer = reset($answer);
    return $answer;
  }

}
